<template>
    <div class="app-container">
        <div style="margin-bottom: 10px">
            <el-button
                type="primary"
                plain
                icon="Plus"
                @click="openDialog('add',{})"
            >新增</el-button>
        </div>

        <!-- 表格数据 -->
        <el-table v-loading="loading" :data="dataList" :border="true">
            <el-table-column label="颁布时间" prop="pubDate" align="center" width="180" />
            <el-table-column label="标题" prop="title" align="center" :show-overflow-tooltip="true" width="400" />
            <el-table-column label="副标题" prop="subTitle" align="center" :show-overflow-tooltip="true" width="400" />
            <el-table-column label="类别" prop="lawType" align="center"  />
            <el-table-column label="颁布机构" prop="pubAgency" align="center"  />
            <el-table-column label="操作" align="center" class-name="small-padding fixed-width" >
                <template #default="scope">
                    <el-button link type="primary"  @click="openDialog('review',scope.row)" >查看</el-button>
                    <el-button link type="primary"  @click="openDialog('edit',scope.row)" >编辑</el-button>
                    <el-button link type="danger"  @click="handleDelete(scope.row)" >删除</el-button>
                </template>
            </el-table-column>
        </el-table>

        <div class="pag-container">
            <el-pagination
                v-model:current-page="data.queryParams.pageNum"
                v-model:page-size="data.queryParams.pageSize"
                :page-sizes="[10,15,20,25]"
                layout="total, sizes, prev, pager, next, jumper"
                :total="total"
                @size-change="handleSizeChange"
                @current-change="handleCurrentChange"
            />
        </div>
        <law-dialog ref="lawRef" @getList="getList"></law-dialog>
    </div>
</template>

<script setup>
import {getCurrentInstance, onMounted, reactive, ref, toRefs} from "vue";
import lawDialog from './components/lawDialog.vue'
import {ElMessage, ElMessageBox} from "element-plus";
import {delLaw, getLawList} from "@/api/backManage/law";
const { proxy } = getCurrentInstance();
const loading = ref(false);
const lawRef = ref();
const data = reactive({
    queryParams: {
        pageNum: 1,
        pageSize: 10,
    },
    total: 0,
    dataList: []
});

const { queryParams, total, dataList } = toRefs(data);

onMounted(() => {
    getList();
});
const getList = async () => {
    loading.value = true;
    const res = await getLawList(data.queryParams);
    if(res.code === 200){
        dataList.value = res.data.list.map(item => {
            return {
                ...item,
                pubDate: item.pubDate.substring(0,10)
            }
        })
        total.value = res.data.total
    }else{
        ElMessage.warning(res.message)
    }
    loading.value = false;
}
const handleSizeChange = (val) => {
    data.queryParams.pageSize = val
    getList()
}
const handleCurrentChange = (val) => {
    data.queryParams.pageNum = val
    getList()
}

const openDialog = (type, value) => {
    lawRef.value.openDialog(type, value);
}

/** 重置新增的表单以及其他数据  */
function reset() {
    proxy.resetForm("roleRef");
}
const handleDelete = (val) => {
    ElMessageBox.confirm(
        '确定删除此条数据？',
        '提示',
        {
            confirmButtonText: '确定',
            cancelButtonText: '取消',
            type: 'warning',
        })
        .then( async() => {
            const res = await delLaw(val);
            if(res.code === 200){
                ElMessage({
                    type: 'success',
                    message: '删除成功'
                });
                getList();
            }else{
                ElMessage.warning(res.message)
            }
        })
}

</script>
<style lang="scss">
.pag-container{
    float: right;
    margin-top: 10px;
}
</style>
